# Test Coverage Report

Generated: Tue 2013-12-10 08:42 CET

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 248 | 202 | 38 | 96.2%
frequently.__init__ | 1 | 1 | 0 | 100.0%
frequently.cms_app | 7 | 0 | 3 | 0.0%
frequently.forms | 45 | 34 | 8 | 91.9%
frequently.models | 49 | 35 | 13 | 97.2%
frequently.templatetags.frequently_tags | 10 | 8 | 2 | 100.0%
frequently.views | 136 | 124 | 12 | 100.0%

Excluded packages and modules
Error packages and modules